from typing import Any, Callable, ClassVar, Dict, List, Optional, Tuple, Union

from typing import overload
import flags
import numpy
import pydrake.common.cpp_template
import pydrake.geometry
import pydrake.math
import pydrake.multibody.parsing
import pydrake.multibody.plant
import pydrake.multibody.tree
import pydrake.solvers
import pydrake.symbolic
import pydrake.systems.framework
RobotDiagramBuilder_: pydrake.common.cpp_template.TemplateClass
RobotDiagram_: pydrake.common.cpp_template.TemplateClass

class BodyShapeDescription:
    @overload
    def __init__(self, shape: pydrake.geometry.Shape, X_BS: pydrake.math.RigidTransform, model_instance_name: str, body_name: str) -> None: ...
    @overload
    def __init__(self, other: BodyShapeDescription) -> None: ...
    def body_name(self) -> str: ...
    def model_instance_name(self) -> str: ...
    def pose_in_body(self) -> pydrake.math.RigidTransform: ...
    def shape(self) -> pydrake.geometry.Shape: ...
    def __copy__(self) -> BodyShapeDescription: ...
    def __deepcopy__(self, arg0: dict) -> BodyShapeDescription: ...

class CollisionChecker:
    def __init__(self, *args, **kwargs) -> None: ...
    def AddCollisionShape(self, group_name: str, description: BodyShapeDescription) -> bool: ...
    def AddCollisionShapeToBody(self, group_name: str, bodyA: pydrake.multibody.tree.Body, shape: pydrake.geometry.Shape, X_AG: pydrake.math.RigidTransform) -> bool: ...
    def AddCollisionShapeToFrame(self, group_name: str, frameA: pydrake.multibody.tree.Frame, shape: pydrake.geometry.Shape, X_AG: pydrake.math.RigidTransform) -> bool: ...
    @overload
    def AddCollisionShapes(self, group_name: str, descriptions: List[BodyShapeDescription]) -> int: ...
    @overload
    def AddCollisionShapes(self, geometry_groups: Dict[str,List[BodyShapeDescription]]) -> Dict[str,int]: ...
    def CalcContextRobotClearance(self, model_context: CollisionCheckerContext, q: numpy.ndarray[numpy.float64[m,1]], influence_distance: float) -> RobotClearance: ...
    def CalcRobotClearance(self, q: numpy.ndarray[numpy.float64[m,1]], influence_distance: float) -> RobotClearance: ...
    def CheckConfigCollisionFree(self, q: numpy.ndarray[numpy.float64[m,1]]) -> bool: ...
    def CheckConfigsCollisionFree(self, configs: List[numpy.ndarray[numpy.float64[m,1]]], parallelize: bool = ...) -> List[int]: ...
    def CheckContextConfigCollisionFree(self, model_context: CollisionCheckerContext, q: numpy.ndarray[numpy.float64[m,1]]) -> bool: ...
    def CheckContextEdgeCollisionFree(self, model_context: CollisionCheckerContext, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> bool: ...
    def CheckEdgeCollisionFree(self, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> bool: ...
    def CheckEdgeCollisionFreeParallel(self, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> bool: ...
    def CheckEdgesCollisionFree(self, edges: List[Tuple[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]]]], parallelize: bool = ...) -> List[int]: ...
    def ClassifyBodyCollisions(self, q: numpy.ndarray[numpy.float64[m,1]]) -> List[RobotCollisionType]: ...
    def ClassifyContextBodyCollisions(self, model_context: CollisionCheckerContext, q: numpy.ndarray[numpy.float64[m,1]]) -> List[RobotCollisionType]: ...
    def Clone(self) -> CollisionChecker: ...
    def ComputeConfigurationDistance(self, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> float: ...
    def GetAllAddedCollisionShapes(self) -> Dict[str,List[BodyShapeDescription]]: ...
    def GetFilteredCollisionMatrix(self) -> numpy.ndarray[numpy.int32[m,n]]: ...
    def GetLargestPadding(self) -> float: ...
    def GetNominalFilteredCollisionMatrix(self) -> numpy.ndarray[numpy.int32[m,n]]: ...
    @overload
    def GetPaddingBetween(self, bodyA_index: pydrake.multibody.tree.BodyIndex, bodyB_index: pydrake.multibody.tree.BodyIndex) -> float: ...
    @overload
    def GetPaddingBetween(self, bodyA: pydrake.multibody.tree.Body, bodyB: pydrake.multibody.tree.Body) -> float: ...
    def GetPaddingMatrix(self) -> numpy.ndarray[numpy.float64[m,n]]: ...
    @overload
    def GetScopedName(self, frame: pydrake.multibody.tree.Frame) -> str: ...
    @overload
    def GetScopedName(self, body: pydrake.multibody.tree.Body) -> str: ...
    def GetZeroConfiguration(self) -> numpy.ndarray[numpy.float64[m,1]]: ...
    def InterpolateBetweenConfigurations(self, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]], ratio: float) -> numpy.ndarray[numpy.float64[m,1]]: ...
    @overload
    def IsCollisionFilteredBetween(self, bodyA_index: pydrake.multibody.tree.BodyIndex, bodyB_index: pydrake.multibody.tree.BodyIndex) -> bool: ...
    @overload
    def IsCollisionFilteredBetween(self, bodyA: pydrake.multibody.tree.Body, bodyB: pydrake.multibody.tree.Body) -> bool: ...
    @overload
    def IsPartOfRobot(self, body: pydrake.multibody.tree.Body) -> bool: ...
    @overload
    def IsPartOfRobot(self, body_index: pydrake.multibody.tree.BodyIndex) -> bool: ...
    def MakeStandaloneConfigurationDistanceFunction(self) -> Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]]],float]: ...
    def MakeStandaloneConfigurationInterpolationFunction(self) -> Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]],float],numpy.ndarray[numpy.float64[m,1]]]: ...
    def MakeStandaloneModelContext(self) -> CollisionCheckerContext: ...
    def MaxContextNumDistances(self, model_context: CollisionCheckerContext) -> int: ...
    def MaxNumDistances(self) -> int: ...
    def MaybeGetUniformRobotEnvironmentPadding(self) -> Optional[float]: ...
    def MaybeGetUniformRobotRobotPadding(self) -> Optional[float]: ...
    def MeasureContextEdgeCollisionFree(self, model_context: CollisionCheckerContext, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> EdgeMeasure: ...
    def MeasureEdgeCollisionFree(self, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> EdgeMeasure: ...
    def MeasureEdgeCollisionFreeParallel(self, q1: numpy.ndarray[numpy.float64[m,1]], q2: numpy.ndarray[numpy.float64[m,1]]) -> EdgeMeasure: ...
    def MeasureEdgesCollisionFree(self, edges: List[Tuple[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]]]], parallelize: bool = ...) -> List[EdgeMeasure]: ...
    def PerformOperationAgainstAllModelContexts(self, operation: Callable[[RobotDiagram,CollisionCheckerContext],None]) -> None: ...
    @overload
    def RemoveAllAddedCollisionShapes(self, group_name: str) -> None: ...
    @overload
    def RemoveAllAddedCollisionShapes(self) -> None: ...
    def SetCollisionFilterMatrix(self, filter_matrix: numpy.ndarray[numpy.int32[m,n]]) -> None: ...
    @overload
    def SetCollisionFilteredBetween(self, bodyA_index: pydrake.multibody.tree.BodyIndex, bodyB_index: pydrake.multibody.tree.BodyIndex, filter_collision: bool) -> None: ...
    @overload
    def SetCollisionFilteredBetween(self, bodyA: pydrake.multibody.tree.Body, bodyB: pydrake.multibody.tree.Body, filter_collision: bool) -> None: ...
    @overload
    def SetCollisionFilteredWithAllBodies(self, body_index: pydrake.multibody.tree.BodyIndex) -> None: ...
    @overload
    def SetCollisionFilteredWithAllBodies(self, body: pydrake.multibody.tree.Body) -> None: ...
    def SetConfigurationDistanceFunction(self, distance_function: Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]]],float]) -> None: ...
    def SetConfigurationInterpolationFunction(self, interpolation_function: Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]],float],numpy.ndarray[numpy.float64[m,1]]]) -> None: ...
    def SetPaddingAllRobotEnvironmentPairs(self, padding: float) -> None: ...
    def SetPaddingAllRobotRobotPairs(self, padding: float) -> None: ...
    @overload
    def SetPaddingBetween(self, bodyA_index: pydrake.multibody.tree.BodyIndex, bodyB_index: pydrake.multibody.tree.BodyIndex, padding: float) -> None: ...
    @overload
    def SetPaddingBetween(self, bodyA: pydrake.multibody.tree.Body, bodyB: pydrake.multibody.tree.Body, padding: float) -> None: ...
    def SetPaddingMatrix(self, collision_padding: numpy.ndarray[numpy.float64[m,n]]) -> None: ...
    def SetPaddingOneRobotBodyAllEnvironmentPairs(self, body_index: pydrake.multibody.tree.BodyIndex, padding: float) -> None: ...
    def SupportsParallelChecking(self) -> bool: ...
    def UpdateContextPositions(self, model_context: CollisionCheckerContext, q: numpy.ndarray[numpy.float64[m,1]]) -> pydrake.systems.framework.Context: ...
    def UpdatePositions(self, q: numpy.ndarray[numpy.float64[m,1]]) -> pydrake.systems.framework.Context: ...
    def edge_step_size(self) -> float: ...
    def get_body(self, body_index: pydrake.multibody.tree.BodyIndex) -> pydrake.multibody.tree.Body: ...
    def model(self) -> RobotDiagram: ...
    def model_context(self) -> CollisionCheckerContext: ...
    def num_allocated_contexts(self) -> int: ...
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant: ...
    def plant_context(self) -> pydrake.systems.framework.Context: ...
    def robot_model_instances(self) -> List[pydrake.multibody.tree.ModelInstanceIndex]: ...
    def set_edge_step_size(self, edge_step_size: float) -> None: ...
    def __copy__(self) -> CollisionChecker: ...
    def __deepcopy__(self, arg0: dict) -> CollisionChecker: ...

class CollisionCheckerContext:
    def __init__(self, model: RobotDiagram) -> None: ...
    def Clone(self) -> CollisionCheckerContext: ...
    def GetQueryObject(self) -> pydrake.geometry.QueryObject: ...
    def model_context(self) -> pydrake.systems.framework.Context: ...
    def plant_context(self) -> pydrake.systems.framework.Context: ...
    def scene_graph_context(self) -> pydrake.systems.framework.Context: ...
    def __copy__(self) -> CollisionCheckerContext: ...
    def __deepcopy__(self, arg0: dict) -> CollisionCheckerContext: ...

class CollisionCheckerParams:
    configuration_distance_function: Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,1]]],float]
    edge_step_size: float
    env_collision_padding: float
    model: RobotDiagram
    robot_model_instances: List[pydrake.multibody.tree.ModelInstanceIndex]
    self_collision_padding: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, **kwargs) -> None: ...

class DirectCollocation(MultipleShooting):
    @overload
    def __init__(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, num_time_samples: int, minimum_time_step: float, maximum_time_step: float, input_port_index: Union[pydrake.systems.framework.InputPortSelection,pydrake.systems.framework.InputPortIndex] = ..., assume_non_continuous_states_are_fixed: bool = ..., prog: pydrake.solvers.MathematicalProgram = ...) -> None: ...
    @overload
    def __init__(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, num_time_samples: int, minimum_timestep: float, maximum_timestep: float, input_port_index: Union[pydrake.systems.framework.InputPortSelection,pydrake.systems.framework.InputPortIndex] = ..., assume_non_continuous_states_are_fixed: bool = ..., prog: pydrake.solvers.MathematicalProgram = ...) -> None: ...

class DirectCollocationConstraint(pydrake.solvers.Constraint):
    def __init__(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, input_port_index: Union[pydrake.systems.framework.InputPortSelection,pydrake.systems.framework.InputPortIndex] = ..., assume_non_continuous_states_are_fixed: bool = ...) -> None: ...

class DirectTranscription(MultipleShooting):
    class TimeStep:
        value: float
        def __init__(self, value: float) -> None: ...
    @overload
    def __init__(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, num_time_samples: int, input_port_index: Union[pydrake.systems.framework.InputPortSelection,pydrake.systems.framework.InputPortIndex] = ...) -> None: ...
    @overload
    def __init__(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, num_time_samples: int, fixed_timestep: DirectTranscription.TimeStep, input_port_index: Union[pydrake.systems.framework.InputPortSelection,pydrake.systems.framework.InputPortIndex] = ...) -> None: ...
    @overload
    def __init__(self, system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, num_time_samples: int, fixed_time_step: DirectTranscription.TimeStep, input_port_index: Union[pydrake.systems.framework.InputPortSelection,pydrake.systems.framework.InputPortIndex] = ...) -> None: ...

class EdgeMeasure:
    @overload
    def __init__(self, distance: float, alpha: float) -> None: ...
    @overload
    def __init__(self, other: EdgeMeasure) -> None: ...
    def alpha(self) -> float: ...
    def alpha_or(self, default_value: float) -> float: ...
    def completely_free(self) -> bool: ...
    def distance(self) -> float: ...
    def partially_free(self) -> bool: ...
    def __copy__(self) -> EdgeMeasure: ...
    def __deepcopy__(self, arg0: dict) -> EdgeMeasure: ...

class GcsTrajectoryOptimization:
    class EdgesBetweenSubgraphs:
        def __init__(self, *args, **kwargs) -> None: ...
        def AddVelocityBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...

    class Subgraph:
        def __init__(self, *args, **kwargs) -> None: ...
        @overload
        def AddPathLengthCost(self, weight_matrix: numpy.ndarray[numpy.float64[m,n]]) -> None: ...
        @overload
        def AddPathLengthCost(self, weight: float = ...) -> None: ...
        def AddTimeCost(self, weight: float = ...) -> None: ...
        def AddVelocityBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...
        def name(self) -> str: ...
        def order(self) -> int: ...
        def regions(self) -> list: ...
        def size(self) -> int: ...
    def __init__(self, num_positions: int) -> None: ...
    def AddEdges(self, from_subgraph: GcsTrajectoryOptimization.Subgraph, to_subgraph: GcsTrajectoryOptimization.Subgraph, subspace: pydrake.geometry.optimization.ConvexSet = ...) -> GcsTrajectoryOptimization.EdgesBetweenSubgraphs: ...
    @overload
    def AddPathLengthCost(self, weight_matrix: numpy.ndarray[numpy.float64[m,n]]) -> None: ...
    @overload
    def AddPathLengthCost(self, weight: float = ...) -> None: ...
    @overload
    def AddRegions(self, regions: List[pydrake.geometry.optimization.ConvexSet], edges_between_regions: List[Tuple[int,int]], order: int, h_min: float = ..., h_max: float = ..., name: str = ...) -> GcsTrajectoryOptimization.Subgraph: ...
    @overload
    def AddRegions(self, regions: List[pydrake.geometry.optimization.ConvexSet], order: int, h_min: float = ..., h_max: float = ..., name: str = ...) -> GcsTrajectoryOptimization.Subgraph: ...
    def AddTimeCost(self, weight: float = ...) -> None: ...
    def AddVelocityBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...
    def GetGraphvizString(self, result: Optional[pydrake.solvers.MathematicalProgramResult] = ..., show_slack: bool = ..., precision: int = ..., scientific: bool = ...) -> str: ...
    def SolvePath(self, *args, **kwargs) -> Any: ...
    def num_positions(self) -> int: ...

class KinematicTrajectoryOptimization:
    def __init__(self, num_positions: int, num_control_points: int, spline_order: int = ..., duration: float = ...) -> None: ...
    def AddAccelerationBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...
    def AddDurationConstraint(self, lb: Optional[float], ub: Optional[float]) -> None: ...
    def AddDurationCost(self, weight: float = ...) -> None: ...
    def AddJerkBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...
    def AddPathAccelerationConstraint(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]], s: float) -> None: ...
    def AddPathLengthCost(self, weight: float = ..., use_conic_constraint: bool = ...) -> None: ...
    @overload
    def AddPathPositionConstraint(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]], s: float) -> None: ...
    @overload
    def AddPathPositionConstraint(self, constraint: pydrake.solvers.Constraint, s: float) -> None: ...
    def AddPathVelocityConstraint(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]], s: float) -> None: ...
    def AddPositionBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...
    def AddVelocityBounds(self, lb: numpy.ndarray[numpy.float64[m,1]], ub: numpy.ndarray[numpy.float64[m,1]]) -> None: ...
    def AddVelocityConstraintAtNormalizedTime(self, constraint: pydrake.solvers.Constraint, s: float) -> None: ...
    def ReconstructTrajectory(self, *args, **kwargs) -> Any: ...
    def SetInitialGuess(self, *args, **kwargs) -> Any: ...
    def basis(self) -> pydrake.math.BsplineBasis: ...
    def control_points(self) -> numpy.ndarray[object[m,n]]: ...
    def duration(self) -> pydrake.symbolic.Variable: ...
    def get_mutable_prog(self) -> pydrake.solvers.MathematicalProgram: ...
    def num_control_points(self) -> int: ...
    def num_positions(self) -> int: ...
    def prog(self) -> pydrake.solvers.MathematicalProgram: ...

class MultipleShooting:
    def __init__(self, *args, **kwargs) -> None: ...
    def AddCompleteTrajectoryCallback(self, callback: Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,n],flags.f_contiguous],numpy.ndarray[numpy.float64[m,n],flags.f_contiguous],List[numpy.ndarray[numpy.float64[m,n],flags.f_contiguous]]],None], names: List[str]) -> pydrake.solvers.Binding𝓣VisualizationCallback𝓤: ...
    @overload
    def AddConstraintToAllKnotPoints(self, f: pydrake.symbolic.Formula) -> List[pydrake.solvers.Binding𝓣Constraint𝓤]: ...
    @overload
    def AddConstraintToAllKnotPoints(self, f: numpy.ndarray[object[m,1]]) -> List[pydrake.solvers.Binding𝓣Constraint𝓤]: ...
    @overload
    def AddConstraintToAllKnotPoints(self, constraint: pydrake.solvers.BoundingBoxConstraint, vars: numpy.ndarray[object[m,1]]) -> List[pydrake.solvers.Binding𝓣BoundingBoxConstraint𝓤]: ...
    @overload
    def AddConstraintToAllKnotPoints(self, constraint: pydrake.solvers.LinearEqualityConstraint, vars: numpy.ndarray[object[m,1]]) -> List[pydrake.solvers.Binding𝓣LinearEqualityConstraint𝓤]: ...
    @overload
    def AddConstraintToAllKnotPoints(self, constraint: pydrake.solvers.LinearConstraint, vars: numpy.ndarray[object[m,1]]) -> List[pydrake.solvers.Binding𝓣LinearConstraint𝓤]: ...
    @overload
    def AddConstraintToAllKnotPoints(self, constraint: pydrake.solvers.Constraint, vars: numpy.ndarray[object[m,1]]) -> List[pydrake.solvers.Binding𝓣Constraint𝓤]: ...
    def AddDurationBounds(self, lower_bound: float, upper_bound: float) -> pydrake.solvers.Binding𝓣LinearConstraint𝓤: ...
    def AddEqualTimeIntervalsConstraints(self) -> List[pydrake.solvers.Binding𝓣LinearConstraint𝓤]: ...
    @overload
    def AddFinalCost(self, e: pydrake.symbolic.Expression) -> pydrake.solvers.Binding𝓣Cost𝓤: ...
    @overload
    def AddFinalCost(self, matrix: numpy.ndarray[object[m,n],flags.f_contiguous]) -> pydrake.solvers.Binding𝓣Cost𝓤: ...
    def AddInputTrajectoryCallback(self, callback: Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,n],flags.f_contiguous]],None]) -> pydrake.solvers.Binding𝓣VisualizationCallback𝓤: ...
    @overload
    def AddRunningCost(self, g: pydrake.symbolic.Expression) -> None: ...
    @overload
    def AddRunningCost(self, g: numpy.ndarray[object[m,n],flags.f_contiguous]) -> None: ...
    def AddStateTrajectoryCallback(self, callback: Callable[[numpy.ndarray[numpy.float64[m,1]],numpy.ndarray[numpy.float64[m,n],flags.f_contiguous]],None]) -> pydrake.solvers.Binding𝓣VisualizationCallback𝓤: ...
    def AddTimeIntervalBounds(self, lower_bound: float, upper_bound: float) -> pydrake.solvers.Binding𝓣BoundingBoxConstraint𝓤: ...
    def GetInputSamples(self, result: pydrake.solvers.MathematicalProgramResult) -> numpy.ndarray[numpy.float64[m,n]]: ...
    def GetSampleTimes(self, result: pydrake.solvers.MathematicalProgramResult) -> numpy.ndarray[numpy.float64[m,1]]: ...
    def GetSequentialVariableAtIndex(self, name: str, index: int) -> numpy.ndarray[object[m,1]]: ...
    def GetSequentialVariableSamples(self, result: pydrake.solvers.MathematicalProgramResult, name: str) -> numpy.ndarray[numpy.float64[m,n]]: ...
    def GetStateSamples(self, result: pydrake.solvers.MathematicalProgramResult) -> numpy.ndarray[numpy.float64[m,n]]: ...
    def NewSequentialVariable(self, rows: int, name: str) -> numpy.ndarray[object[m,1]]: ...
    def ReconstructInputTrajectory(self, *args, **kwargs) -> Any: ...
    def ReconstructStateTrajectory(self, *args, **kwargs) -> Any: ...
    def SetInitialTrajectory(self, *args, **kwargs) -> Any: ...
    def final_state(self) -> numpy.ndarray[object[m,1]]: ...
    def fixed_time_step(self) -> float: ...
    def fixed_timestep(self) -> float: ...
    def initial_state(self) -> numpy.ndarray[object[m,1]]: ...
    @overload
    def input(self) -> numpy.ndarray[object[m,1]]: ...
    @overload
    def input(self, index: int) -> numpy.ndarray[object[m,1]]: ...
    def prog(self) -> pydrake.solvers.MathematicalProgram: ...
    @overload
    def state(self) -> numpy.ndarray[object[m,1]]: ...
    @overload
    def state(self, index: int) -> numpy.ndarray[object[m,1]]: ...
    def time(self) -> numpy.ndarray[object[1,1]]: ...
    def time_step(self, index: int) -> numpy.ndarray[object[1,1]]: ...
    def timestep(self, index: int) -> numpy.ndarray[object[1,1]]: ...

class RobotClearance:
    @overload
    def __init__(self, num_positions: int) -> None: ...
    @overload
    def __init__(self, other: RobotClearance) -> None: ...
    def Append(self, *args, **kwargs) -> Any: ...
    def Reserve(self, size: int) -> None: ...
    def collision_types(self, *args, **kwargs) -> Any: ...
    def distances(self) -> numpy.ndarray[numpy.float64[m,1]]: ...
    def jacobians(self) -> numpy.ndarray[numpy.float64[m,n],flags.c_contiguous]: ...
    def mutable_jacobians(self) -> numpy.ndarray[numpy.float64[m,n],flags.writeable,flags.c_contiguous]: ...
    def num_positions(self) -> int: ...
    def other_indices(self) -> List[pydrake.multibody.tree.BodyIndex]: ...
    def robot_indices(self) -> List[pydrake.multibody.tree.BodyIndex]: ...
    def size(self) -> int: ...
    def __copy__(self) -> RobotClearance: ...
    def __deepcopy__(self, arg0: dict) -> RobotClearance: ...

class RobotCollisionType:
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    _pybind11_del_orig: ClassVar[None] = ...
    kEnvironmentAndSelfCollision: ClassVar[RobotCollisionType] = ...
    kEnvironmentCollision: ClassVar[RobotCollisionType] = ...
    kNoCollision: ClassVar[RobotCollisionType] = ...
    kSelfCollision: ClassVar[RobotCollisionType] = ...
    def __init__(self, value: int) -> None: ...
    def MakeUpdated(self, *args, **kwargs) -> Any: ...
    def __del__(self, *args, **kwargs) -> Any: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class RobotDiagram(pydrake.systems.framework.Diagram):
    def __init__(self, *args, **kwargs) -> None: ...
    def mutable_plant_context(self, root_context: pydrake.systems.framework.Context) -> pydrake.systems.framework.Context: ...
    def mutable_scene_graph(self) -> pydrake.geometry.SceneGraph: ...
    def mutable_scene_graph_context(self, root_context: pydrake.systems.framework.Context) -> pydrake.systems.framework.Context: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant: ...
    @overload
    def plant(self, readonly) -> Any: ...
    def plant_context(self, root_context: pydrake.systems.framework.Context) -> pydrake.systems.framework.Context: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph: ...
    def scene_graph_context(self, root_context: pydrake.systems.framework.Context) -> pydrake.systems.framework.Context: ...

class RobotDiagramBuilder:
    def __init__(self, time_step: float = ...) -> None: ...
    def Build(self) -> RobotDiagram: ...
    def IsDiagramBuilt(self) -> bool: ...
    def builder(self) -> pydrake.systems.framework.DiagramBuilder: ...
    def parser(self) -> pydrake.multibody.parsing.Parser: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant: ...
    @overload
    def plant(self, mutable) -> Any: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph: ...

class RobotDiagramBuilder_𝓣AutoDiffXd𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, time_step: float = ...) -> None: ...
    def Build(self) -> RobotDiagram_𝓣AutoDiffXd𝓤: ...
    def IsDiagramBuilt(self) -> bool: ...
    def builder(self) -> pydrake.systems.framework.DiagramBuilder_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self, mutable) -> Any: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣AutoDiffXd𝓤: ...

class RobotDiagramBuilder_𝓣Expression𝓤:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, time_step: float = ...) -> None: ...
    def Build(self) -> RobotDiagram_𝓣Expression𝓤: ...
    def IsDiagramBuilt(self) -> bool: ...
    def builder(self) -> pydrake.systems.framework.DiagramBuilder_𝓣Expression𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣Expression𝓤: ...
    @overload
    def plant(self, mutable) -> Any: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣Expression𝓤: ...

class RobotDiagram_𝓣AutoDiffXd𝓤(pydrake.systems.framework.Diagram_𝓣AutoDiffXd𝓤):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def mutable_plant_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...
    def mutable_scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣AutoDiffXd𝓤: ...
    def mutable_scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self, readonly) -> Any: ...
    def plant_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣AutoDiffXd𝓤: ...
    def scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...

class RobotDiagram_𝓣Expression𝓤(pydrake.systems.framework.Diagram_𝓣Expression𝓤):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def mutable_plant_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...
    def mutable_scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣Expression𝓤: ...
    def mutable_scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣Expression𝓤: ...
    @overload
    def plant(self, readonly) -> Any: ...
    def plant_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣Expression𝓤: ...
    def scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...

class SceneGraphCollisionChecker(CollisionChecker):
    def __init__(self, *args, **kwargs) -> None: ...

class UnimplementedCollisionChecker(CollisionChecker):
    def __init__(self, *args, **kwargs) -> None: ...

class _TemporaryName_N5drake8planning12RobotDiagramIN5Eigen14AutoDiffScalarINS2_6MatrixIdLin1ELi1ELi0ELin1ELi1EEEEEEE(pydrake.systems.framework.Diagram_𝓣AutoDiffXd𝓤):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def mutable_plant_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...
    def mutable_scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣AutoDiffXd𝓤: ...
    def mutable_scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self, readonly) -> Any: ...
    def plant_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣AutoDiffXd𝓤: ...
    def scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤) -> pydrake.systems.framework.Context_𝓣AutoDiffXd𝓤: ...

class _TemporaryName_N5drake8planning12RobotDiagramINS_8symbolic10ExpressionEEE(pydrake.systems.framework.Diagram_𝓣Expression𝓤):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def mutable_plant_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...
    def mutable_scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣Expression𝓤: ...
    def mutable_scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣Expression𝓤: ...
    @overload
    def plant(self, readonly) -> Any: ...
    def plant_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣Expression𝓤: ...
    def scene_graph_context(self, root_context: pydrake.systems.framework.Context_𝓣Expression𝓤) -> pydrake.systems.framework.Context_𝓣Expression𝓤: ...

class _TemporaryName_N5drake8planning19RobotDiagramBuilderIN5Eigen14AutoDiffScalarINS2_6MatrixIdLin1ELi1ELi0ELin1ELi1EEEEEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, time_step: float = ...) -> None: ...
    def Build(self) -> RobotDiagram_𝓣AutoDiffXd𝓤: ...
    def IsDiagramBuilt(self) -> bool: ...
    def builder(self) -> pydrake.systems.framework.DiagramBuilder_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣AutoDiffXd𝓤: ...
    @overload
    def plant(self, mutable) -> Any: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣AutoDiffXd𝓤: ...

class _TemporaryName_N5drake8planning19RobotDiagramBuilderINS_8symbolic10ExpressionEEE:
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, time_step: float = ...) -> None: ...
    def Build(self) -> RobotDiagram_𝓣Expression𝓤: ...
    def IsDiagramBuilt(self) -> bool: ...
    def builder(self) -> pydrake.systems.framework.DiagramBuilder_𝓣Expression𝓤: ...
    @overload
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant_𝓣Expression𝓤: ...
    @overload
    def plant(self, mutable) -> Any: ...
    def scene_graph(self) -> pydrake.geometry.SceneGraph_𝓣Expression𝓤: ...

@overload
def AddDirectCollocationConstraint(constraint: DirectCollocationConstraint, time_step: numpy.ndarray[object[m,1]], state: numpy.ndarray[object[m,1]], next_state: numpy.ndarray[object[m,1]], input: numpy.ndarray[object[m,1]], next_input: numpy.ndarray[object[m,1]], prog: pydrake.solvers.MathematicalProgram) -> pydrake.solvers.Binding𝓣Constraint𝓤: ...
@overload
def AddDirectCollocationConstraint(constraint: DirectCollocationConstraint, timestep: numpy.ndarray[object[m,1]], state: numpy.ndarray[object[m,1]], next_state: numpy.ndarray[object[m,1]], input: numpy.ndarray[object[m,1]], next_input: numpy.ndarray[object[m,1]], prog: pydrake.solvers.MathematicalProgram) -> pydrake.solvers.Binding𝓣Constraint𝓤: ...
def MakeBodyShapeDescription(plant: pydrake.multibody.plant.MultibodyPlant, plant_context: pydrake.systems.framework.Context, geometry_id: pydrake.geometry.GeometryId) -> BodyShapeDescription: ...
